#!/bin/bash

# Creates a tarball out of content at the specified directory path.

usage() {
    cat <<EOF
Usage:
    $0 [--include-vcs] [--include-vcs-ignores] path dir_name source_name

    Creates a compressed tarball out of the
    specified path content. Uses tar to do the job.
    By default, omits any VCS-specific files
    as well as files mentioned in a VCS-ignore file.

Options:
    -h, --help             Print help
    --include-vcs          Include version control system directories. By default excluded.
    --include-vcs-ignores  Include files that match patterns present in VCS-specific ignore file. By default excluded.

Arguments:
    path                   Path to the content that should be packed.
    dir_name               Name of the directory in the created tarball.
    source_name            Name of the resulting tarball file.
EOF
}

CONTENT_PATH=""
DIR_NAME=""
SOURCE_NAME=""
EXCLUDE_VCS="--exclude-vcs"
EXCLUDE_VCS_IGNORES="--exclude-vcs-ignores"

while [ -n "$1" ] ; do
    case "$1" in
    -h|--help)
        usage
        exit 0
        ;;
    --include-vcs)
        EXCLUDE_VCS=""
        ;;
    --include-vcs-ignores)
        EXCLUDE_VCS_IGNORES=""
        ;;
    *)
        CONTENT_PATH="$(realpath "$1")"
        shift
        DIR_NAME="$1"
        shift
        SOURCE_NAME="$1"
        ;;
    esac
    shift
done

if [ -z "$CONTENT_PATH" ] || [ -z "$SOURCE_NAME" ] || [ -z "$DIR_NAME" ]; then
    usage
    exit -1
fi

tar caf "$SOURCE_NAME" "$EXCLUDE_VCS" "$EXCLUDE_VCS_IGNORES" --absolute-names --transform "s|^$CONTENT_PATH|$DIR_NAME/|" --transform "s|^$DIR_NAME//*|$DIR_NAME/|" $CONTENT_PATH
